CONFIG_FILE = 'settings.ini'

SPECIAL_KEYS = {
	'alt': 'alt',
	'tab': 'Tab',
	'control': 'ctrl',
	'delete': 'Delete',
}

NUMBERS_MAP = {
	'zero': '0',
	'one': '1',
	'two': '2',
	'three': '3',
	'four': '4',
	'five': '5',
	'six': '6',
	'seven': '7',
	'eight': '8',
	'nine': '9',
	'won': '1',
	'to': '2',
	'too': '2',
	'for': '4',
	"i've": '5',
    'sex': '6',
}


XDOTOOL_MAP = {
	' ': '0x0020',
	'!': '0x0021',
	'"': '0x0022',
        '%': '0x0025',
	"'": '0x0027',
	'(': '0x0028',
	')': '0x0029',
	',': '0x002C',
	'-': '0x002D',
	'.': '0x002E',
	':': '0x003A',
	'\\': '0x005C',
	'[': '0x005B',
	']': '0x005D',
	'_': '0x005F',
	'^': '0x0AFC',
}

HOMONYMS = {
    'args': ['arcs', 'our', 'arts', 'arms', 'are', "arby's", 'earns', 'orange',
        'birds', 'outs', 'ours'],
    'dent': ["didn't"],
    'down': ['dumb'],
    'hi': ['high', 'fight'],
    'kill': ['kills', 'killed'],
    'line': ['wine', 'wind', 'lines'],
    'main': ['made', 'maid'],
    'save': ['say'],
    'end': ['and'],
    'shell': ['shall'],
    'sell': ['sale', 'cell'],
    'lend': ['land'],
}
